@@ -29,6 +29,41 @@ pub mod http_utils;
 pub mod http_parts;
 pub mod request;
 pub mod response;
+pub mod headers;
+pub mod interaction;
+pub mod sync_interaction;
+pub mod message;
+pub mod pact;
+pub mod sync_pact;
+pub mod message_pact;
+
+/// A "prelude" or a default list of import types to include.
+pub mod prelude {
+  pub use crate::{Consumer, Provider};
+  pub use crate::bodies::OptionalBody;
+  pub use crate::content_types::ContentType;
+  pub use crate::expression_parser::DataType;
+  pub use crate::generators::{Generator, GeneratorCategory, Generators};
+  pub use crate::interaction::Interaction;
+  pub use crate::matchingrules::{Category, MatchingRuleCategory, MatchingRules, RuleLogic};
+  pub use crate::message_pact::MessagePact;
+  pub use crate::pact::Pact;
+  pub use crate::PactSpecification;
+  pub use crate::provider_states::ProviderState;
+  pub use crate::request::Request;
+  pub use crate::response::Response;
+  pub use crate::sync_interaction::RequestResponseInteraction;
+  pub use crate::sync_pact::RequestResponsePact;
+  pub use crate::http_utils::HttpAuth;
+
+  pub mod v4 {
+    pub use crate::v4::pact::V4Pact;
+    pub use crate::v4::synch_http::SynchronousHttp;
+  }
+}
+
+/// Version of the library
+pub const PACT_RUST_VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 
 /// Enum defining the pact specification versions supported by the library
 #[repr(C)]
@@ -174,7 +209,7 @@ impl Consumer {
 }
 
 impl PactJsonVerifier for Consumer {
-  fn verify_json(path: &str, pact_json: &Value, strict: bool) -> Vec<PactFileVerificationResult> {
+  fn verify_json(path: &str, pact_json: &Value, strict: bool, _spec_version: PactSpecification) -> Vec<PactFileVerificationResult> {
     let mut results = vec![];
 
     match pact_json {
@@ -244,7 +279,7 @@ impl Provider {
 }
 
 impl PactJsonVerifier for Provider {
-  fn verify_json(path: &str, pact_json: &Value, strict: bool) -> Vec<PactFileVerificationResult> {
+  fn verify_json(path: &str, pact_json: &Value, strict: bool, _spec_version: PactSpecification) -> Vec<PactFileVerificationResult> {
     let mut results = vec![];
 
     match pact_json {
